Documentation
¶
Overview ¶
Package v1 is the v1 version of the API. +groupName=jenkins.io
Index ¶
- Variables
- func Kind(kind string) schema.GroupKind
- func Resource(resource string) schema.GroupResource
- type ActivityStatusType
- type ActivityStepKindType
- type CommitSummary
- type CoreActivityStep
- type Environment
- type EnvironmentKindType
- type EnvironmentList
- type EnvironmentRepository
- type EnvironmentRepositoryType
- type EnvironmentSpec
- type EnvironmentStatus
- type GitService
- type GitServiceList
- type GitServiceSpec
- type GitStatus
- type IssueSummary
- type PipelineActivity
- type PipelineActivityList
- type PipelineActivitySpec
- type PipelineActivityStatus
- type PipelineActivityStep
- type PreviewGitSpec
- type PromoteActivityStep
- type PromotePullRequestStep
- type PromoteUpdateStep
- type PromotionStrategyType
- type Release
- type ReleaseList
- type ReleaseSpec
- type ReleaseStatus
- type ReleaseStatusType
- type StageActivityStep
- type TeamSettings
- type UserDetails
- type UserSpec
Constants ¶
This section is empty.
Variables ¶
var ( // SchemeBuilder for building the schema :) SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme helper AddToScheme = SchemeBuilder.AddToScheme )
var PromotionStrategyTypeValues = []string{ string(PromotionStrategyTypeAutomatic), string(PromotionStrategyTypeManual), string(PromotionStrategyTypeNever), }
PromotionStrategyTypeValues is the list of all values
var SchemeGroupVersion = schema.GroupVersion{Group: jenkinsio.GroupName, Version: jenkinsio.Version}
SchemeGroupVersion is group version used to register these objects
Functions ¶
func Resource ¶
func Resource(resource string) schema.GroupResource
Resource takes an unqualified resource and returns a Group qualified GroupResource
Types ¶
type ActivityStatusType ¶ added in v1.0.84
type ActivityStatusType string
ActivityStatusType is the status of an activity; usually succeeded or failed/error on completion
const ( // ActivityStatusTypeNone an activity step has not started yet ActivityStatusTypeNone ActivityStatusType = "" // ActivityStatusTypePending an activity step is waiting to start ActivityStatusTypePending ActivityStatusType = "Pending" // ActivityStatusTypeRunning an activity is running ActivityStatusTypeRunning ActivityStatusType = "Running" // ActivityStatusTypeSucceeded an activity completed successfully ActivityStatusTypeSucceeded ActivityStatusType = "Succeeded" // ActivityStatusTypeFailed an activity failed ActivityStatusTypeFailed ActivityStatusType = "Failed" // ActivityStatusTypeWaitingForApproval an activity is waiting for approval ActivityStatusTypeWaitingForApproval ActivityStatusType = "WaitingForApproval" // ActivityStatusTypeError there is some error with an activity ActivityStatusTypeError ActivityStatusType = "Error" )
func (ActivityStatusType) String ¶ added in v1.0.84
func (s ActivityStatusType) String() string
type ActivityStepKindType ¶ added in v1.0.87
type ActivityStepKindType string
ActivityStepKindType is a kind of step
const ( // ActivityStepKindTypeNone no kind yet ActivityStepKindTypeNone ActivityStepKindType = "" // ActivityStepKindTypeStage a group of low level steps ActivityStepKindTypeStage ActivityStepKindType = "Stage" // ActivityStepKindTypePromote a promote activity ActivityStepKindTypePromote ActivityStepKindType = "Promote" )
type CommitSummary ¶ added in v1.0.90
type CommitSummary struct {
Message string `json:"message,omitempty" protobuf:"bytes,1,opt,name=message"`
SHA string `json:"sha,omitempty" protobuf:"bytes,2,opt,name=sha"`
URL string `json:"url,omitempty" protobuf:"bytes,3,opt,name=url"`
Author *UserDetails `json:"author,omitempty" protobuf:"bytes,4,opt,name=author"`
Committer *UserDetails `json:"committer,omitempty" protobuf:"bytes,5,opt,name=committer"`
Branch string `json:"branch,omitempty" protobuf:"bytes,6,opt,name=branch"`
IssueIDs []string `json:"issueIds,omitempty" protobuf:"bytes,7,opt,name=issueIds"`
}
CommitSummary is the summary of a commit
func (*CommitSummary) DeepCopy ¶ added in v1.0.90
func (in *CommitSummary) DeepCopy() *CommitSummary
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CommitSummary.
func (*CommitSummary) DeepCopyInto ¶ added in v1.0.90
func (in *CommitSummary) DeepCopyInto(out *CommitSummary)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type CoreActivityStep ¶ added in v1.0.84
type CoreActivityStep struct {
Name string `json:"name,omitempty" protobuf:"bytes,1,opt,name=name"`
Description string `json:"description,omitempty" protobuf:"bytes,2,opt,name=description"`
Status ActivityStatusType `json:"status,omitempty" protobuf:"bytes,3,opt,name=status"`
StartedTimestamp *metav1.Time `json:"startedTimestamp,omitempty" protobuf:"bytes,4,opt,name=startedTimestamp"`
CompletedTimestamp *metav1.Time `json:"completedTimestamp,omitempty" protobuf:"bytes,5,opt,name=completedTimestamp"`
}
CoreActivityStep is a base step included in Stages of a pipeline or other kinds of step
func (*CoreActivityStep) DeepCopy ¶ added in v1.0.84
func (in *CoreActivityStep) DeepCopy() *CoreActivityStep
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CoreActivityStep.
func (*CoreActivityStep) DeepCopyInto ¶ added in v1.0.84
func (in *CoreActivityStep) DeepCopyInto(out *CoreActivityStep)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type Environment ¶
type Environment struct {
metav1.TypeMeta `json:",inline"`
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
Spec EnvironmentSpec `json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
Status EnvironmentStatus `json:"status,omitempty" protobuf:"bytes,3,opt,name=status"`
}
Environment represents an environment like Dev, Test, Staging, Production where code lives
func (*Environment) DeepCopy ¶
func (in *Environment) DeepCopy() *Environment
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Environment.
func (*Environment) DeepCopyInto ¶
func (in *Environment) DeepCopyInto(out *Environment)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Environment) DeepCopyObject ¶
func (in *Environment) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EnvironmentKindType ¶ added in v1.0.18
type EnvironmentKindType string
EnvironmentKindType is the kind of an environment
const ( // EnvironmentKindTypePermanent specifies that the environment is a regular permanent one EnvironmentKindTypePermanent EnvironmentKindType = "Permanent" // EnvironmentKindTypePreview specifies that an environment is a Preview environment that lasts as long as a Pull Request EnvironmentKindTypePreview EnvironmentKindType = "Preview" // EnvironmentKindTypeTest specifies that an environment is a temporary one for a test EnvironmentKindTypeTest EnvironmentKindType = "Test" // EnvironmentKindTypeEdit specifies that an environment is a developers editing workspace EnvironmentKindTypeEdit EnvironmentKindType = "Edit" // EnvironmentKindTypeDevelopment specifies that an environment is a development environment; for developer tools like Jenkins, Nexus etc EnvironmentKindTypeDevelopment EnvironmentKindType = "Development" )
func (EnvironmentKindType) IsPermanent ¶ added in v1.0.83
func (e EnvironmentKindType) IsPermanent() bool
IsPermanent returns true if this environment is permanent
type EnvironmentList ¶
type EnvironmentList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []Environment `json:"items"`
}
EnvironmentList is a list of TypeMeta resources
func (*EnvironmentList) DeepCopy ¶
func (in *EnvironmentList) DeepCopy() *EnvironmentList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentList.
func (*EnvironmentList) DeepCopyInto ¶
func (in *EnvironmentList) DeepCopyInto(out *EnvironmentList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*EnvironmentList) DeepCopyObject ¶
func (in *EnvironmentList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type EnvironmentRepository ¶
type EnvironmentRepository struct {
Kind EnvironmentRepositoryType `json:"kind,omitempty" protobuf:"bytes,1,opt,name=kind"`
URL string `json:"url,omitempty" protobuf:"bytes,2,opt,name=url"`
Ref string `json:"ref,omitempty" protobuf:"bytes,3,opt,name=ref"`
}
EnvironmentRepository is the repository for an environment using GitOps
func (*EnvironmentRepository) DeepCopy ¶
func (in *EnvironmentRepository) DeepCopy() *EnvironmentRepository
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentRepository.
func (*EnvironmentRepository) DeepCopyInto ¶
func (in *EnvironmentRepository) DeepCopyInto(out *EnvironmentRepository)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnvironmentRepositoryType ¶
type EnvironmentRepositoryType string
EnvironmentRepositoryType is the repository type
const ( // EnvironmentRepositoryTypeGit specifies that a git repository is used EnvironmentRepositoryTypeGit EnvironmentRepositoryType = "Git" )
type EnvironmentSpec ¶
type EnvironmentSpec struct {
Label string `json:"label,omitempty" protobuf:"bytes,1,opt,name=label"`
Namespace string `json:"namespace,omitempty" protobuf:"bytes,2,opt,name=namespace"`
Cluster string `json:"cluster,omitempty" protobuf:"bytes,3,opt,name=cluster"`
PromotionStrategy PromotionStrategyType `json:"promotionStrategy,omitempty" protobuf:"bytes,4,opt,name=promotionStrategy"`
Source EnvironmentRepository `json:"source,omitempty" protobuf:"bytes,5,opt,name=source"`
Order int32 `json:"order,omitempty" protobuf:"bytes,6,opt,name=order"`
Kind EnvironmentKindType `json:"kind,omitempty" protobuf:"bytes,7,opt,name=kind"`
PullRequestURL string `json:"pullRequestURL,omitempty" protobuf:"bytes,8,opt,name=pullRequestURL"`
TeamSettings TeamSettings `json:"teamSettings,omitempty" protobuf:"bytes,9,opt,name=teamSettings"`
PreviewGitSpec PreviewGitSpec `json:"previewGitInfo,omitempty" protobuf:"bytes,10,opt,name=previewGitInfo"`
}
EnvironmentSpec is the specification of an Environment
func (*EnvironmentSpec) DeepCopy ¶
func (in *EnvironmentSpec) DeepCopy() *EnvironmentSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentSpec.
func (*EnvironmentSpec) DeepCopyInto ¶
func (in *EnvironmentSpec) DeepCopyInto(out *EnvironmentSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type EnvironmentStatus ¶
type EnvironmentStatus struct {
Version string `json:"version,omitempty"`
}
EnvironmentStatus is the status for an Environment resource
func (*EnvironmentStatus) DeepCopy ¶
func (in *EnvironmentStatus) DeepCopy() *EnvironmentStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new EnvironmentStatus.
func (*EnvironmentStatus) DeepCopyInto ¶
func (in *EnvironmentStatus) DeepCopyInto(out *EnvironmentStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GitService ¶ added in v1.0.114
type GitService struct {
metav1.TypeMeta `json:",inline"`
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
Spec GitServiceSpec `json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
}
GitService represents a git provider so we can map the host name to a kinda of git service
func (*GitService) DeepCopy ¶ added in v1.0.114
func (in *GitService) DeepCopy() *GitService
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GitService.
func (*GitService) DeepCopyInto ¶ added in v1.0.114
func (in *GitService) DeepCopyInto(out *GitService)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GitService) DeepCopyObject ¶ added in v1.0.114
func (in *GitService) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GitServiceList ¶ added in v1.0.114
type GitServiceList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []GitService `json:"items"`
}
GitServiceList is a list of GitService resources
func (*GitServiceList) DeepCopy ¶ added in v1.0.114
func (in *GitServiceList) DeepCopy() *GitServiceList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GitServiceList.
func (*GitServiceList) DeepCopyInto ¶ added in v1.0.114
func (in *GitServiceList) DeepCopyInto(out *GitServiceList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*GitServiceList) DeepCopyObject ¶ added in v1.0.114
func (in *GitServiceList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type GitServiceSpec ¶ added in v1.0.114
type GitServiceSpec struct {
GitKind string `json:"gitKind,omitempty" protobuf:"bytes,1,opt,name=gitKind"`
URL string `json:"url,omitempty" protobuf:"bytes,2,opt,name=host"`
Name string `json:"name,omitempty" protobuf:"bytes,3,opt,name=host"`
}
GitServiceSpec is the specification of an GitService
func (*GitServiceSpec) DeepCopy ¶ added in v1.0.114
func (in *GitServiceSpec) DeepCopy() *GitServiceSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GitServiceSpec.
func (*GitServiceSpec) DeepCopyInto ¶ added in v1.0.114
func (in *GitServiceSpec) DeepCopyInto(out *GitServiceSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type GitStatus ¶ added in v1.0.87
type GitStatus struct {
URL string `json:"url,omitempty" protobuf:"bytes,1,opt,name=url"`
Status string `json:"status,omitempty" protobuf:"bytes,2,opt,name=status"`
}
GitStatus the status of a git commit in terms of CI/CD
func (*GitStatus) DeepCopy ¶ added in v1.0.87
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new GitStatus.
func (*GitStatus) DeepCopyInto ¶ added in v1.0.87
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type IssueSummary ¶ added in v1.0.97
type IssueSummary struct {
ID string `json:"id,omitempty" protobuf:"bytes,1,opt,name=id"`
URL string `json:"url,omitempty" protobuf:"bytes,2,opt,name=url"`
Title string `json:"title,omitempty" protobuf:"bytes,3,opt,name=title"`
Body string `json:"body,omitempty" protobuf:"bytes,4,opt,name=body"`
State string `json:"state,omitempty" protobuf:"bytes,5,opt,name=state"`
Message string `json:"message,omitempty" protobuf:"bytes,6,opt,name=message"`
User *UserDetails `json:"user,omitempty" protobuf:"bytes,7,opt,name=user"`
Assignees []UserDetails `json:"assignees,omitempty" protobuf:"bytes,8,opt,name=assignees"`
ClosedBy *UserDetails `json:"closedBy,omitempty" protobuf:"bytes,9,opt,name=closedBy"`
}
IssueSummary is the summary of an issue
func (*IssueSummary) DeepCopy ¶ added in v1.0.97
func (in *IssueSummary) DeepCopy() *IssueSummary
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new IssueSummary.
func (*IssueSummary) DeepCopyInto ¶ added in v1.0.97
func (in *IssueSummary) DeepCopyInto(out *IssueSummary)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*IssueSummary) IsClosed ¶ added in v1.0.101
func (i *IssueSummary) IsClosed() bool
IsClosed returns true if this issue is closed or fixed
type PipelineActivity ¶ added in v1.0.84
type PipelineActivity struct {
metav1.TypeMeta `json:",inline"`
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
Spec PipelineActivitySpec `json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
Status PipelineActivityStatus `json:"status,omitempty" protobuf:"bytes,3,opt,name=status"`
}
PipelineActivity represents pipeline activity for a particular run of a pipeline
func (*PipelineActivity) DeepCopy ¶ added in v1.0.84
func (in *PipelineActivity) DeepCopy() *PipelineActivity
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineActivity.
func (*PipelineActivity) DeepCopyInto ¶ added in v1.0.84
func (in *PipelineActivity) DeepCopyInto(out *PipelineActivity)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PipelineActivity) DeepCopyObject ¶ added in v1.0.84
func (in *PipelineActivity) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PipelineActivityList ¶ added in v1.0.84
type PipelineActivityList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []PipelineActivity `json:"items"`
}
PipelineActivityList is a list of PipelineActivity resources
func (*PipelineActivityList) DeepCopy ¶ added in v1.0.84
func (in *PipelineActivityList) DeepCopy() *PipelineActivityList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineActivityList.
func (*PipelineActivityList) DeepCopyInto ¶ added in v1.0.84
func (in *PipelineActivityList) DeepCopyInto(out *PipelineActivityList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*PipelineActivityList) DeepCopyObject ¶ added in v1.0.84
func (in *PipelineActivityList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type PipelineActivitySpec ¶ added in v1.0.84
type PipelineActivitySpec struct {
Pipeline string `json:"pipeline,omitempty" protobuf:"bytes,1,opt,name=pipeline"`
Build string `json:"build,omitempty" protobuf:"bytes,2,opt,name=build"`
Version string `json:"version,omitempty" protobuf:"bytes,3,opt,name=version"`
Status ActivityStatusType `json:"status,omitempty" protobuf:"bytes,4,opt,name=status"`
StartedTimestamp *metav1.Time `json:"startedTimestamp,omitempty" protobuf:"bytes,5,opt,name=startedTimestamp"`
CompletedTimestamp *metav1.Time `json:"completedTimestamp,omitempty" protobuf:"bytes,6,opt,name=completedTimestamp"`
Steps []PipelineActivityStep `json:"steps,omitempty" protobuf:"bytes,7,opt,name=steps"`
BuildURL string `json:"buildUrl,omitempty" protobuf:"bytes,8,opt,name=buildUrl"`
BuildLogsURL string `json:"buildLogsUrl,omitempty" protobuf:"bytes,9,opt,name=buildLogsUrl"`
GitURL string `json:"gitUrl,omitempty" protobuf:"bytes,10,opt,name=gitUrl"`
GitRepository string `json:"gitRepository,omitempty" protobuf:"bytes,10,opt,name=gitRepository"`
GitOwner string `json:"gitOwner,omitempty" protobuf:"bytes,10,opt,name=gitOwner"`
ReleaseNotesURL string `json:"releaseNotesURL,omitempty" protobuf:"bytes,11,opt,name=releaseNotesURL"`
}
PipelineActivitySpec is the specification of the pipeline activity
func (*PipelineActivitySpec) DeepCopy ¶ added in v1.0.84
func (in *PipelineActivitySpec) DeepCopy() *PipelineActivitySpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineActivitySpec.
func (*PipelineActivitySpec) DeepCopyInto ¶ added in v1.0.84
func (in *PipelineActivitySpec) DeepCopyInto(out *PipelineActivitySpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PipelineActivityStatus ¶ added in v1.0.84
type PipelineActivityStatus struct {
Version string `json:"version,omitempty" protobuf:"bytes,1,opt,name=version"`
}
PipelineActivityStatus is the status for an Environment resource
func (*PipelineActivityStatus) DeepCopy ¶ added in v1.0.84
func (in *PipelineActivityStatus) DeepCopy() *PipelineActivityStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineActivityStatus.
func (*PipelineActivityStatus) DeepCopyInto ¶ added in v1.0.84
func (in *PipelineActivityStatus) DeepCopyInto(out *PipelineActivityStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PipelineActivityStep ¶ added in v1.0.84
type PipelineActivityStep struct {
Kind ActivityStepKindType `json:"kind,omitempty" protobuf:"bytes,1,opt,name=kind"`
Stage *StageActivityStep `json:"stage,omitempty" protobuf:"bytes,2,opt,name=stage"`
Promote *PromoteActivityStep `json:"promote,omitempty" protobuf:"bytes,3,opt,name=promote"`
}
PipelineActivityStep represents a step in a pipeline activity
func (*PipelineActivityStep) DeepCopy ¶ added in v1.0.84
func (in *PipelineActivityStep) DeepCopy() *PipelineActivityStep
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PipelineActivityStep.
func (*PipelineActivityStep) DeepCopyInto ¶ added in v1.0.84
func (in *PipelineActivityStep) DeepCopyInto(out *PipelineActivityStep)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PreviewGitSpec ¶ added in v1.0.22
type PreviewGitSpec struct {
Name string `json:"name,omitempty" protobuf:"bytes,1,opt,name=name"`
URL string `json:"url,omitempty" protobuf:"bytes,2,opt,name=url"`
User UserSpec `json:"user,omitempty" protobuf:"bytes,3,opt,name=user"`
Title string `json:"title,omitempty" protobuf:"bytes,4,opt,name=title"`
Description string `json:"description,omitempty" protobuf:"bytes,5,opt,name=description"`
BuildStatus string `json:"buildStatus,omitempty" protobuf:"bytes,6,opt,name=buildStatus"`
BuildStatusURL string `json:"buildStatusUrl,omitempty" protobuf:"bytes,7,opt,name=buildStatusUrl"`
ApplicationName string `json:"appName,omitempty" protobuf:"bytes,8,opt,name=appName"`
}
PreviewGitSpec is the preview git branch/pull request details
func (*PreviewGitSpec) DeepCopy ¶ added in v1.0.22
func (in *PreviewGitSpec) DeepCopy() *PreviewGitSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PreviewGitSpec.
func (*PreviewGitSpec) DeepCopyInto ¶ added in v1.0.22
func (in *PreviewGitSpec) DeepCopyInto(out *PreviewGitSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PromoteActivityStep ¶ added in v1.0.87
type PromoteActivityStep struct {
CoreActivityStep
Environment string `json:"environment,omitempty" protobuf:"bytes,1,opt,name=environment"`
PullRequest *PromotePullRequestStep `json:"pullRequest,omitempty" protobuf:"bytes,2,opt,name=pullRequest"`
Update *PromoteUpdateStep `json:"update,omitempty" protobuf:"bytes,3,opt,name=update"`
ApplicationURL string `json:"applicationURL,omitempty" protobuf:"bytes,4,opt,name=environment"`
}
PromoteActivityStep is the step of promoting a version of an application to an environment
func (*PromoteActivityStep) DeepCopy ¶ added in v1.0.87
func (in *PromoteActivityStep) DeepCopy() *PromoteActivityStep
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PromoteActivityStep.
func (*PromoteActivityStep) DeepCopyInto ¶ added in v1.0.87
func (in *PromoteActivityStep) DeepCopyInto(out *PromoteActivityStep)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PromotePullRequestStep ¶ added in v1.0.84
type PromotePullRequestStep struct {
CoreActivityStep
PullRequestURL string `json:"pullRequestURL,omitempty" protobuf:"bytes,1,opt,name=pullRequestURL"`
MergeCommitSHA string `json:"mergeCommitSHA,omitempty" protobuf:"bytes,2,opt,name=mergeCommitSHA"`
}
PromotePullRequestStep is the step for promoting a version to an environment by raising a Pull Request on the git repository of the environment
func (*PromotePullRequestStep) DeepCopy ¶ added in v1.0.84
func (in *PromotePullRequestStep) DeepCopy() *PromotePullRequestStep
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PromotePullRequestStep.
func (*PromotePullRequestStep) DeepCopyInto ¶ added in v1.0.84
func (in *PromotePullRequestStep) DeepCopyInto(out *PromotePullRequestStep)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PromoteUpdateStep ¶ added in v1.0.87
type PromoteUpdateStep struct {
CoreActivityStep
Statuses []GitStatus `json:"statuses,omitempty" protobuf:"bytes,1,opt,name=statuses"`
}
PromoteUpdateStep is the step for updating a promotion after the Pull Request merges to master
func (*PromoteUpdateStep) DeepCopy ¶ added in v1.0.87
func (in *PromoteUpdateStep) DeepCopy() *PromoteUpdateStep
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new PromoteUpdateStep.
func (*PromoteUpdateStep) DeepCopyInto ¶ added in v1.0.87
func (in *PromoteUpdateStep) DeepCopyInto(out *PromoteUpdateStep)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type PromotionStrategyType ¶
type PromotionStrategyType string
PromotionStrategyType is the type of a promotion strategy
const ( // PromotionStrategyTypeManual specifies that promotion happens manually PromotionStrategyTypeManual PromotionStrategyType = "Manual" // PromotionStrategyTypeAutomatic specifies that promotion happens automatically PromotionStrategyTypeAutomatic PromotionStrategyType = "Auto" // PromotionStrategyTypeNever specifies that promotion is disabled for this environment PromotionStrategyTypeNever PromotionStrategyType = "Never" )
type Release ¶ added in v1.0.90
type Release struct {
metav1.TypeMeta `json:",inline"`
// Standard object's metadata.
// More info: https://git.k8s.io/community/contributors/devel/api-conventions.md#metadata
// +optional
metav1.ObjectMeta `json:"metadata,omitempty" protobuf:"bytes,1,opt,name=metadata"`
Spec ReleaseSpec `json:"spec,omitempty" protobuf:"bytes,2,opt,name=spec"`
Status ReleaseStatus `json:"status,omitempty" protobuf:"bytes,3,opt,name=status"`
}
Release represents a single version of an app that has been released
func (*Release) DeepCopy ¶ added in v1.0.90
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new Release.
func (*Release) DeepCopyInto ¶ added in v1.0.90
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*Release) DeepCopyObject ¶ added in v1.0.90
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ReleaseList ¶ added in v1.0.90
type ReleaseList struct {
metav1.TypeMeta `json:",inline"`
metav1.ListMeta `json:"metadata"`
Items []Release `json:"items"`
}
ReleaseList is a list of Release resources
func (*ReleaseList) DeepCopy ¶ added in v1.0.90
func (in *ReleaseList) DeepCopy() *ReleaseList
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ReleaseList.
func (*ReleaseList) DeepCopyInto ¶ added in v1.0.90
func (in *ReleaseList) DeepCopyInto(out *ReleaseList)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*ReleaseList) DeepCopyObject ¶ added in v1.0.90
func (in *ReleaseList) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type ReleaseSpec ¶ added in v1.0.90
type ReleaseSpec struct {
Name string `json:"name,omitempty" protobuf:"bytes,1,opt,name=name"`
Version string `json:"version,omitempty" protobuf:"bytes,2,opt,name=version"`
GitHTTPURL string `json:"gitHttpUrl,omitempty" protobuf:"bytes,3,opt,name=gitHttpUrl"`
GitCloneURL string `json:"gitCloneUrl,omitempty" protobuf:"bytes,4,opt,name=gitCloneUrl"`
Commits []CommitSummary `json:"commits,omitempty" protobuf:"bytes,5,opt,name=commits"`
Issues []IssueSummary `json:"issues,omitempty" protobuf:"bytes,6,opt,name=issues"`
PullRequests []IssueSummary `json:"pullRequests,omitempty" protobuf:"bytes,7,opt,name=pullRequests"`
ReleaseNotesURL string `json:"releaseNotesURL,omitempty" protobuf:"bytes,8,opt,name=releaseNotesURL"`
GitRepository string `json:"gitRepository,omitempty" protobuf:"bytes,9,opt,name=gitRepository"`
GitOwner string `json:"gitOwner,omitempty" protobuf:"bytes,10,opt,name=gitOwner"`
}
ReleaseSpec is the specification of the Release
func (*ReleaseSpec) DeepCopy ¶ added in v1.0.90
func (in *ReleaseSpec) DeepCopy() *ReleaseSpec
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ReleaseSpec.
func (*ReleaseSpec) DeepCopyInto ¶ added in v1.0.90
func (in *ReleaseSpec) DeepCopyInto(out *ReleaseSpec)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ReleaseStatus ¶ added in v1.0.90
type ReleaseStatus struct {
Status ReleaseStatusType `json:"status,omitempty" protobuf:"bytes,1,opt,name=status"`
}
ReleaseStatus is the status of a release
func (*ReleaseStatus) DeepCopy ¶ added in v1.0.90
func (in *ReleaseStatus) DeepCopy() *ReleaseStatus
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new ReleaseStatus.
func (*ReleaseStatus) DeepCopyInto ¶ added in v1.0.90
func (in *ReleaseStatus) DeepCopyInto(out *ReleaseStatus)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type ReleaseStatusType ¶ added in v1.0.90
type ReleaseStatusType string
ReleaseStatusType is the status of a release; usually deployed or failed at completion
const ( // ReleaseStatusTypeNone an activity step has not started yet ReleaseStatusTypeNone ReleaseStatusType = "" // ReleaseStatusTypePending the release is pending ReleaseStatusTypePending ReleaseStatusType = "Pending" // ReleaseStatusTypeDeployed a release has been deployed ReleaseStatusTypeDeployed ReleaseStatusType = "Deployed" // ReleaseStatusTypeFailed release failed ReleaseStatusTypeFailed ReleaseStatusType = "Failed" )
type StageActivityStep ¶ added in v1.0.84
type StageActivityStep struct {
CoreActivityStep
Steps []CoreActivityStep `json:"steps,omitempty" protobuf:"bytes,1,opt,name=steps"`
}
StageActivityStep represents a stage of zero to more sub steps in a jenkins pipeline
func (*StageActivityStep) DeepCopy ¶ added in v1.0.84
func (in *StageActivityStep) DeepCopy() *StageActivityStep
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new StageActivityStep.
func (*StageActivityStep) DeepCopyInto ¶ added in v1.0.84
func (in *StageActivityStep) DeepCopyInto(out *StageActivityStep)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type TeamSettings ¶ added in v1.0.58
type TeamSettings struct {
UseGitOPs bool `json:"useGitOps,omitempty" protobuf:"bytes,1,opt,name=useGitOps"`
AskOnCreate bool `json:"askOnCreate,omitempty" protobuf:"bytes,1,opt,name=askOnCreate"`
}
TeamSettings the default settings for a team
func (*TeamSettings) DeepCopy ¶ added in v1.0.83
func (in *TeamSettings) DeepCopy() *TeamSettings
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new TeamSettings.
func (*TeamSettings) DeepCopyInto ¶ added in v1.0.83
func (in *TeamSettings) DeepCopyInto(out *TeamSettings)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type UserDetails ¶ added in v1.0.90
type UserDetails struct {
Login string `json:"login,omitempty" protobuf:"bytes,1,opt,name=login"`
Name string `json:"name,omitempty" protobuf:"bytes,2,opt,name=name"`
Email string `json:"email,omitempty" protobuf:"bytes,3,opt,name=email"`
CreationTimestamp *metav1.Time `json:"creationTimestamp,omitempty" protobuf:"bytes,4,opt,name=creationTimestamp"`
URL string `json:"url,omitempty" protobuf:"bytes,5,opt,name=url"`
AvatarURL string `json:"avatarUrl,omitempty" protobuf:"bytes,6,opt,name=avatarUrl"`
}
UserDetails containers details of a user
func (*UserDetails) DeepCopy ¶ added in v1.0.90
func (in *UserDetails) DeepCopy() *UserDetails
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UserDetails.
func (*UserDetails) DeepCopyInto ¶ added in v1.0.90
func (in *UserDetails) DeepCopyInto(out *UserDetails)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type UserSpec ¶ added in v1.0.25
type UserSpec struct {
Username string `json:"username,omitempty" protobuf:"bytes,1,opt,name=username"`
Name string `json:"name,omitempty" protobuf:"bytes,2,opt,name=name"`
LinkURL string `json:"linkUrl,omitempty" protobuf:"bytes,3,opt,name=linkUrl"`
ImageURL string `json:"imageUrl,omitempty" protobuf:"bytes,4,opt,name=imageUrl"`
}
UserSpec is the user details
func (*UserSpec) DeepCopy ¶ added in v1.0.25
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new UserSpec.
func (*UserSpec) DeepCopyInto ¶ added in v1.0.25
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.